Module engine

Module engine 

Rules evaluation engine

The engine evaluates rules against incoming state changes and events, producing actions that the router should execute.

Structs

PendingAction
Output from rule evaluation – an action the router should execute
RulesEngine
The rules engine evaluates rules against state changes.